@@ -1,6 +1,6 @@
-/*	$Id: kcgi.h,v 1.78 2015/07/16 21:49:48 kristaps Exp $ */
+/*	$Id: kcgi.h,v 1.84 2016/01/07 07:31:53 kristaps Exp $ */
 /*
- * Copyright (c) 2012, 2014, 2015 Kristaps Dzonsons <kristaps@bsd.lv>
+ * Copyright (c) 2012, 2014, 2015, 2016 Kristaps Dzonsons <kristaps@bsd.lv>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -294,6 +294,9 @@ enum	kpairstate {
 	KPAIR_INVALID
 };
 
+#define KREQ_DEBUG_WRITE	  0x01
+#define KREQ_DEBUG_READ_BODY	  0x02
+
 struct	kpair {
 	char		*key; /* key name */
 	size_t		 keypos; /* bucket (if assigned) */
@@ -361,6 +364,7 @@ struct	khttpbasic {
 struct	khttpauth {
 	enum kauth	 type;
 	int		 authorised;
+	char		*digest;
 	union {
 		struct khttpdigest digest;
 		struct khttpbasic basic;
@@ -446,7 +450,8 @@ enum kcgi_err	 khttp_parsex(struct kreq *, const struct kmimemap *,
 			const char *const *, size_t, 
 			const struct kvalid *, size_t,
 			const char *const *, size_t,
-			size_t, size_t, void *, void (*)(void *));
+			size_t, size_t, void *, void (*)(void *),
+			unsigned int);
 void		 khttp_putc(struct kreq *, int);
 void		 khttp_puts(struct kreq *, const char *);
 int		 khttp_template(struct kreq *, 
@@ -459,6 +464,11 @@ int		 khttp_templatex_buf(const struct ktemplate *,
 			const char *, size_t, ktemplate_writef, void *);
 void		 khttp_write(struct kreq *, const char *, size_t);
 
+int		 khttpdigest_validate(const struct kreq *, 
+			const char *);
+int		 khttpbasic_validate(const struct kreq *, 
+			const char *, const char *);
+
 int		 kvalid_date(struct kpair *);
 int		 kvalid_double(struct kpair *);
 int		 kvalid_email(struct kpair *);
@@ -468,20 +478,19 @@ int		 kvalid_stringne(struct kpair *);
 int		 kvalid_udouble(struct kpair *);
 int		 kvalid_uint(struct kpair *);
 
-enum kcgi_err	 khttp_fcgi_parse(struct kfcgi *, struct kreq *, 
-			const char *const *, size_t, size_t);
-enum kcgi_err	 khttp_fcgi_parsex(struct kfcgi *, struct kreq *, 
-			const struct kmimemap *, 
-			const char *const *, size_t,
-			size_t, size_t, void *);
+enum kcgi_err	 khttp_fcgi_parse(struct kfcgi *, struct kreq *);
 enum kcgi_err	 khttp_fcgi_init(struct kfcgi **, 
-			const struct kvalid *, size_t);
+			const struct kvalid *, size_t,
+			const char *const *, size_t, size_t);
 enum kcgi_err	 khttp_fcgi_initx(struct kfcgi **, 
 			const char *const *, size_t,
 			const struct kvalid *, size_t, 
-			void *, void (*)(void *));
+			const struct kmimemap *, size_t,
+			const char *const *, size_t, size_t,
+			void *, void (*)(void *), unsigned int);
 enum kcgi_err	 khttp_fcgi_free(struct kfcgi *);
 void		 khttp_fcgi_child_free(struct kfcgi *);
+int		 khttp_fcgi_test(void);
 
 char		*kutil_urlabs(enum kscheme, const char *, 
 			uint16_t, const char *);
